## pyirecovery
A CLI wrapper of pymobiledevice3 that interacts with Recovery/DFU Apple devices
# Installation
* Install with PIP:
```
python3 -m pip install pyirecovery
```
* Install locally:
```
git clone https://github.com/Mini-Exploit/pyirecovery
cd pyirecovery
bash ./install.sh
```
# Usage
* Run `pyirecovery` and see the usage

# Credits
* [doronz88](https://github.com/doronz88) - [pymobiledevice3](https://github.com/doronz88/pymobiledevice3)
